# Telebot Utils 🤖

Collection of utils for pyTelegramBotAPI to develop awesome Telegram Bots.

## Installation

To install the package run the following command in your terminal:

```
pip install telebot-utils
```

## Usage

To use the utilities that the telebot-utils package provide you need to import it in your script:

```python
import telebot_utils
```

## License

[LICENSE.md](LICENSE.md)

## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md)
